const { cli, testCommand } = require('./cli');

const PIPE = '|';
const BASHPROFILE = '~/.bash_profile';

async function gitClone(repoPath, destDir) {
  try {
    await cli('git', 'clone', `https://github.com/${repoPath}.git`, destDir);
  } catch (err) {
    console.log(`${err.message}`);
    throw err;
  }
}

async function echo(msg, redirectionPath = null) {
  try {
    await cli('echo', msg, `> ${redirectionPath}`);
  } catch (err) {
    console.log(`${err.message}`);
    throw err;
  }
}

// $ rbenv install -l | egrep "\s[0-9]\.[0-9]\.[0-9]$" | tail -1
async function getLatestRubyVersion() {
  try {
    await cli(
      'rbenv install -l',
      PIPE,
      'grep',
      '-e',
      's[0-9].[0-9].[0-9]$',
      PIPE,
      'tail -1',
    );
  } catch (err) {
    console.log(`${err.message}`);
    throw err;
  }
}

async function installRuby() {
  try {
    // await cli('yum update');
    await cli(
      ...[  'yum',
            'install',
            '-y',
            'git-core',
            'zlib',
            'zlib-devel',
            'gcc-c++',
            'patch',
            'readline',
            'readline-devel',
            'libyaml-devel',
            'libffi-devel',
            'openssl-devel',
            'make',
            'bzip2',
            'autoconf',
            'automake',
            'libtool',
            'bison',
            'curl',
            'sqlite-devel'
          ]
    );
    
  } catch (err) {
    console.log(`${err.message}`);
    throw err;
  }
}

module.exports = async (version = null) => {
  try {
    await installRuby();
    console.log("Successfully installed ruby")
  } catch (err) {
    throw err
  }
  // TODO: Add Support for JIT compilation

  // return cli('ruby', '-v')
};
